;; Generated package description from window-tool-bar.el  -*- no-byte-compile: t -*-
(define-package "window-tool-bar" "0.2.1.0.20241024.85007" "Add tool bars inside windows" '((emacs "27.1") (compat "29.1")) :commit "8903106bb783c2825233c149b6799960aacdea57" :url "https://elpa.gnu.org/packages/window-tool-bar.html" :authors '(("Jared Finder" . "jared@finder.org")) :maintainer '("Jared Finder" . "jared@finder.org") :keywords '("mouse"))
